"use strict";

var _inherits = function (child, parent) {
  child.prototype = Object.create(parent && parent.prototype, {
    constructor: {
      value: child,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (parent) child.__proto__ = parent;
};

var Declaration = require("./declaration");
var Container = require("./container");
var Comment = require("./comment");
var AtRule = require("./at-rule");
var Result = require("./result");
var Rule = require("./rule");

// Root of CSS
var Root = function Root(defaults) {
  this.type = "root";
  this.nodes = [];
  Container.call(this, defaults);
};

_inherits(Root, Container);

// Fix space when we remove first child
Root.prototype.remove = function (child) {
  child = this.index(child);

  if (child === 0 && this.nodes.length > 1) {
    this.nodes[1].before = this.nodes[child].before;
  }

  return Container.prototype.remove.call(this, child);
};

// Fix spaces on insert before first rule
Root.prototype.normalize = function (child, sample, type) {
  var nodes = Container.prototype.normalize.call(this, child);

  if (sample) {
    if (type == "prepend") {
      if (this.nodes.length > 1) {
        sample.before = this.nodes[1].before;
      } else {
        delete sample.before;
      }
    } else {
      for (var i = 0; i < nodes.length; i++) {
        if (this.first != sample) nodes[i].before = sample.before;
      }
    }
  }

  return nodes;
};

// Stringify styles
Root.prototype.stringify = function (builder) {
  this.stringifyContent(builder);
  if (this.after) builder(this.after);
};

// Generate processing result with optional source map
Root.prototype.toResult = function (opts) {
  if (opts === undefined) opts = {};
  return new Result(this, opts);
};

module.exports = Root;